package eu.etaxonomy.taxeditor.molecular.handler;


import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.TreeNode;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.model.molecular.Sequence;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.molecular.TaxeditorMolecularPlugin;
import eu.etaxonomy.taxeditor.molecular.editor.AlignmentEditor;
import eu.etaxonomy.taxeditor.molecular.editor.AlignmentEditorInput;



/**
 * Opens the alignment editor from the CDM tree.
 *
 * @author Ben St&ouml;ver
 * @author pplitzner
 */
public class EditSequenceHandler extends AbstractHandler {

    org.apache.log4j.Logger logger = org.apache.log4j.Logger.getLogger(EditSequenceHandler.class);

    @Override
    public Object execute(ExecutionEvent event) throws ExecutionException {
        ISelection currentSelection = HandlerUtil.getCurrentSelection(event);
        TreeNode treeNodeOfSelection = EditorUtil.getTreeNodeOfSelection(currentSelection);
        if(treeNodeOfSelection != null && treeNodeOfSelection.getValue() instanceof Sequence){
            AlignmentEditorInput input = new AlignmentEditorInput(((Sequence)treeNodeOfSelection.getValue()).getUuid());  //TODO Should there always be a new instance created here? What if the specified CDM node is already opened in an AlignmentEditor? => Possible create Singleton that keeps instances by sequence objects in a map.
            try {
                TaxeditorMolecularPlugin.getDefault().getWorkbench()
                .getActiveWorkbenchWindow().getActivePage().openEditor(input, AlignmentEditor.ID);
            }
            catch (PartInitException e) {
                logger.error("Could not open AlignmentEditor", e);
            }
        }
        return null;
    }
}
