package eu.etaxonomy.taxeditor.molecular.handler;


import info.bioinfweb.libralign.pherogram.model.PherogramComponentModel;

import java.net.URI;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.TreeNode;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.model.media.MediaUtils;
import eu.etaxonomy.cdm.model.molecular.SingleRead;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.molecular.TaxeditorMolecularPlugin;
import eu.etaxonomy.taxeditor.molecular.editor.AlignmentEditor;
import eu.etaxonomy.taxeditor.molecular.editor.PherogramViewPart;



/**
 * Displays an undistorted pherogram with {@link PherogramViewPart}.
 *
 * @author Ben Stöver
 *
 */
public class ShowPherogramHandler extends AbstractHandler {
	public static void showPherogram(PherogramComponentModel model) throws PartInitException {
		PherogramViewPart.createView(model);
	}


	@Override
	public Object execute(ExecutionEvent event) throws ExecutionException {
		ISelection currentSelection = HandlerUtil.getCurrentSelection(event);
		TreeNode treeNodeOfSelection = EditorUtil.getTreeNodeOfSelection(currentSelection);
		if (treeNodeOfSelection != null && treeNodeOfSelection.getValue() instanceof SingleRead) {
		    //TODO Can the parent node (containing the cut positions) be extracted from SingleRead?
			try {
			    SingleRead singleRead = (SingleRead)treeNodeOfSelection.getValue();
			    URI uri = null;
			    if (singleRead.getPherogram() != null) {  // Pherogram objects without URI are possible.
			        uri = MediaUtils.getFirstMediaRepresentationPart(singleRead.getPherogram()).getUri();
			    }

			    if (uri == null) {
	                MessagingUtils.messageDialog("No pherogram available", this,
	                        "The selected read does not have an associated pherogram.");
			    }
			    else {
	              showPherogram(new PherogramComponentModel(AlignmentEditor.readPherogram(uri)));
			    }
			}
	        catch (Exception e) {
	            MessagingUtils.errorDialog("Error", null, e.getLocalizedMessage(), TaxeditorMolecularPlugin.PLUGIN_ID,
	                    e, false);
	        }
        }
        return null;
    }
}
